#version 150

uniform sampler2D DiffuseSampler;

uniform vec2 InSize;
uniform vec2 BlurDir;

in vec2 texCoord;
in vec2 texelSize;

out vec4 fragColor;

#define SQRT_TWO_PI 2.506628274
#define GAUSSIAN_KERNEL_SIZE 64

vec3 BloomSample(vec2 sampleCoord) 
{
    return texture(DiffuseSampler, sampleCoord).rgb;
}

vec3 Bloom() 
{
    vec2 texelStep = texelSize * BlurDir;
    vec3 filteredColor = BloomSample(texCoord);
    float sigma = float(GAUSSIAN_KERNEL_SIZE) / 3.0;
    float normalizer = 1.0 / (sigma * SQRT_TWO_PI);
    float doubleSigmaSqr = 2 * sigma * sigma;

    for (int i = 1; i < GAUSSIAN_KERNEL_SIZE; ++i) 
    {
        float weight = exp(-float(i * i) / doubleSigmaSqr);
        filteredColor += BloomSample(texCoord + texelStep * float(i)) * weight;
        filteredColor += BloomSample(texCoord - texelStep * float(i)) * weight;
    }
    return filteredColor * normalizer;
}

void main() 
{
    fragColor = vec4(Bloom(), 1.0);
}
